@@ -1,6 +1,8 @@
 #include <iostream>
 #include <cmath>
+#ifdef _OPENMP
 # include <omp.h>
+#endif
 #include <RcppArmadillo.h>
 #include "header.h"
 
